************
Installation
************

.. _install:

To install :mod:`rayoptics` using pip, use

.. code::

    > pip install rayoptics

Alternatively, :mod:`rayoptics` can be installed from the conda-forge channel using conda

.. code::

   > conda install rayoptics --channel conda-forge
